==> oarepo_model_builder_files-4.0.1-py3-none-any.whl: oarepo_model_builder_files/datatypes/components/parent_record.py <==
from oarepo_model_builder.datatypes import DataTypeComponent, ModelDataType
from oarepo_model_builder.datatypes.components import (
    DefaultsModelComponent,
    RecordMetadataModelComponent,
    ServiceModelComponent,
)
from oarepo_model_builder.datatypes.components.model.utils import (
    append_array,
    prepend_array,
)


class ParentRecordComponent(DataTypeComponent):
    eligible_datatypes = [ModelDataType]
    depends_on = [
        DefaultsModelComponent,
        RecordMetadataModelComponent,
        ServiceModelComponent,
    ]

    def before_model_prepare(self, datatype, *, context, **kwargs):
        if context["profile"] == "files":
            return
        prepend_array(datatype, "record-metadata", "base-classes", "RecordMetadataBase")
        prepend_array(datatype, "record-metadata", "base-classes", "db.Model")

        append_array(
            datatype,
            "record-metadata",
            "imports",
            {"import": "invenio_db.db"},
        )
        append_array(
            datatype,
            "record-metadata",
            "imports",
            {"import": "invenio_records.models.RecordMetadataBase"},
        )

        append_array(
            datatype,
            "service-config",
            "imports",
            {
                "import": "invenio_records_resources.services.records.components.FilesOptionsComponent"
            },
        )
        append_array(datatype, "service-config", "components", "FilesOptionsComponent")

==> oarepo_model_builder_files-4.0.4-py3-none-any.whl: oarepo_model_builder_files/datatypes/components/parent_record.py <==
from oarepo_model_builder.datatypes import DataTypeComponent, ModelDataType
from oarepo_model_builder.datatypes.components import (
    DefaultsModelComponent,
    RecordMetadataModelComponent,
    ServiceModelComponent,
)
from oarepo_model_builder.datatypes.components.model.utils import (
    append_array,
    prepend_array,
)


class ParentRecordComponent(DataTypeComponent):
    eligible_datatypes = [ModelDataType]
    depends_on = [
        DefaultsModelComponent,
        RecordMetadataModelComponent,
        ServiceModelComponent,
    ]

    def before_model_prepare(self, datatype, *, context, **kwargs):
        if context["profile"] != "record":
            return
        # have files plugin in virtualenv but there are no files in the record
        if 'files' not in datatype.definition:
            return
        prepend_array(datatype, "record-metadata", "base-classes", "RecordMetadataBase")
        prepend_array(datatype, "record-metadata", "base-classes", "db.Model")

        append_array(
            datatype,
            "record-metadata",
            "imports",
            {"import": "invenio_db.db"},
        )
        append_array(
            datatype,
            "record-metadata",
            "imports",
            {"import": "invenio_records.models.RecordMetadataBase"},
        )

        append_array(
            datatype,
            "service-config",
            "imports",
            {
                "import": "invenio_records_resources.services.records.components.FilesOptionsComponent"
            },
        )
        append_array(datatype, "service-config", "components", "FilesOptionsComponent")
